@@ -1,6 +1,6 @@
 package Parse::Dia::SQL;
 
-# $Id: SQL.pm,v 1.52 2010/05/21 05:25:11 aff Exp $
+# $Id: SQL.pm,v 1.55 2011/02/16 10:23:11 aff Exp $
 
 =pod
 
@@ -47,6 +47,10 @@ See L<http://tedia2sql.tigris.org/usingtedia2sql.html>
 
 =item * Preliminary support for Dia's I<database> shapes is added. 
 
+=item * Table comments are used as I<table postfix options>.  This
+means per-table options (e.g. partitioning options) are supported on a
+per-database level.
+
 =back
 
 =head1 DIA VERSIONS
@@ -190,7 +194,7 @@ use Parse::Dia::SQL::Output::Sas;
 use Parse::Dia::SQL::Output::Sybase;
 use Parse::Dia::SQL::Output::SQLite3;
 
-our $VERSION = '0.16';
+our $VERSION = '0.18';
 
 my $UML_ASSOCIATION  = 'UML - Association';
 my $UML_SMALLPACKAGE = 'UML - SmallPackage';
@@ -241,6 +245,7 @@ sub new {
     diaversion     => $param{diaversion} || undef,
     ignore_type_mismatch => $param{ignore_type_mismatch} || undef,
     converted            => 0,
+    loglevel    => $param{loglevel} || undef,
   };
 
   bless($self, $class);
@@ -264,7 +269,7 @@ sub new {
 # Initialize logger
 sub _init_log {
   my $self = shift;
-  my $logger = Parse::Dia::SQL::Logger::->new();
+  my $logger = Parse::Dia::SQL::Logger::->new(loglevel => $self->{loglevel});
   $self->{log} = $logger->get_logger(__PACKAGE__);
   return 1;
 }
@@ -282,6 +287,7 @@ sub _init_utils {
   $self->{utils} = Parse::Dia::SQL::Utils::->new(
     db         => $self->{db},
     default_pk => $self->{default_pk},
+    loglevel   => $self->{loglevel},
   );
   return 1;
 }
@@ -315,7 +321,7 @@ sub get_output_instance {
   # Add some args to param unless they are set by caller
   %param =
     map { $param{$_} = $self->{$_} unless exists($param{$_}); $_ => $param{$_} }
-      qw(classes associations small_packages components files index_options typemap);
+      qw(classes associations small_packages components files index_options typemap loglevel);
 
   if ($self->{db} eq q{db2}) {
   return Parse::Dia::SQL::Output::DB2->new(%param);
@@ -1375,8 +1381,8 @@ sub _parse_association {
     # many-to-many; generate the centre (join) table, its constraints
     # and the classes' primary keys (if needed)
     $ok = $self->generate_many_to_many_association(
-      $assocName,  $leftClass, $leftEnd{'role'},
-      $rightClass, $rightEnd{'role'}
+      $assocName,  $leftClass, $rightEnd{'role'},
+      $rightClass, $leftEnd{'role'}
     );
   }
   else {
@@ -1917,7 +1923,7 @@ sub save_foreign_key {
     $targetTable, $rightEnd,  $constraintAction
     ];
 
-  $self->{log}->debug("save_foreign_key: fk_defs is now: " . Dumper($self->{fk_defs}));
+  $self->{log}->debug("save_foreign_key: fk_defs is now: " . Dumper($self->{fk_defs})) if $self->{log}->is_debug();
 
   return 1;
 }
